# OneDrive / SharePoint Bulk Downloader

<badges>[![version](https://img.shields.io/pypi/v/onedrive.svg)](https://pypi.org/project/onedrive/)
[![license](https://img.shields.io/pypi/l/onedrive.svg)](https://pypi.org/project/onedrive/)
[![pyversions](https://img.shields.io/pypi/pyversions/onedrive.svg)](https://pypi.org/project/onedrive/)  
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![powered](https://img.shields.io/badge/Powered%20by-UTF8-red.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>Download shared folders with Selenium in bulk.</i>

# Hierarchy

```
onedrive
|---- OneDrive()
'---- SharePoint()
```

# Example

## python
```python

```
